#
# spec file for package regal
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           regal
Version:        0.34.0
Release:        1.1
Summary:        Linter and language server for Rego
License:        Apache-2.0
URL:            https://github.com/StyraInc/regal
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
Regal is a linter and language server for Rego, making your Rego magnificent,
and you the ruler of rules!

With its extensive set of linter rules, documentation and editor integrations,
Regal is the perfect companion for policy development, whether you're an
experienced Rego developer or just starting out.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       zsh
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -tags="regal_standalone regal_enable_novelty" \
   -ldflags=" \
   -X github.com/styrainc/regal/pkg/version.Version=%{version} \
   -X github.com/styrainc/regal/pkg/version.Commit=${COMMIT_HASH} \
   -X github.com/styrainc/regal/pkg/version.Hostname=build.opensuse.org \
   -X github.com/styrainc/regal/pkg/version.Timestamp=${BUILD_DATE}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sat May 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.34.0:
  After a month of development, we're happy to announce Regal
  v0.34. This version of the OPA community's favorite linter and
  language server brings you new 3 linter rules, performance
  improvements and much more.
  With the v0.34.0 release, Regal now ships with more than 100
  linter rules!
  Which is pretty close to one new week per rule since the project
  started.
  * New rules
  - unresolved-reference
    This one is particularly exciting! The new
    unresolved-reference rule reports any references (like
    data.users.permissions) that cannot be resolved (i.e. found)
    anywhere in the project. Some projects will have valid
    references that can't be resolved at the time Regal lints the
    project, and the rule provides configuration options to mark
    certain references, or entire paths (like data.users.*) as
    resolved. See the docs for the rule for more details.
  - pointless-import
    Category: imports
    The new pointless-import rule will flags imports of the same
    package, and other import forms where the import has no real
    effect.
  - single-item-in
    Category: idiomatic
    The single-item-in rule reports cases of in being used on a
    single item collection, and suggests using an equality check
    instead.
  * Performance
  - Use OPA v1.5.0, which brings performance improvements to walk
    reducing linting time by about 10%%.
  - Faster linting by avoiding walk in a few locations where
    possible.
  - Improve performance of aggregate rules.
  - Several performance optimizations to Regal's linter rules.
  * API
  - The linter API now has a new Prepare method that can be used
    to prepare the linter before reusing it across several runs.
  * Various
  - Some rules that would previously only scan the topmost level
    of a rule body will now recursively scan the whole rule.
  - The input completions provider has been rewritten in Rego
    (previously Go).
  - The automatic version check has been rewritten in Rego
    (previously Go).
  * Bugs
  - Fix false positive in custom one-liner-rule.
  * Docs
  - Updated roadmap. Go check it out!
  - Move rules table from README and into a more interactive form
    on the Styra docs. Take a look!
  - Add link to Renovating Rego blog.
  - README: add link to KubeCon London talk, which prominently
    featured Regal.
  - Update links to adapt to OPA's new documentation.
  - Update outdated information in README.
  * Dependencies
  - build(deps): bump the dependencies group with 2 updates
    (#1551)
  - build(deps): bump the dependencies group with 2 updates
    (#1544)
  - build(deps): bump the dependencies group with 2 updates
    (#1521)
  - build(deps): bump github/codeql-action in the dependencies
    group (#1507)
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.33.1:
  This release is the same tag as v0.33.1, please see that release
  for the release notes.
  Another v0.33.1 was released to trigger the rebuilding of some
  assets that were deleted in a draft release.
  * New Rule: in-wildcard-key
    Using a wildcard variable (_) for the key in the key-value form
    of iteration (some _, value in collection) is never needed, and
    can be replaced by the simple some value in … form . This rule
    flags cases where the key iteration is redundant. (Read more)
  * New Rule: confusing-alias
    While import aliases can improve readability, aliasing an
    import reference that is also imported without an alias is
    confusing, as both names point to the same resource. This rule
    catches such cases. (Read more)
  * New Rule: mixed-iteration
    Rego supports different styles of collection iteration. While
    "reference style" iteration (collection[_]) can be concise for
    deeply nested structures, mixing it with the some .. in style
    within a single iteration expression makes for code that’s more
    difficult to follow. This rule encourages consistency within a
    single iteration statement. (Read more)
  * New Rule: narrow-argument
    This new rule analyzes function arguments to suggest narrowing
    them down to the minimal value the function depends on. This
    can improve clarity and reusability. The rule considers
    incrementally defined functions across all their definitions.
    This is a powerful but opinionated rule and is thus in the
    custom category and is not on by default. See the documentation
    for how to enable it if you’re curious to try it out! (Read
    more)
  * Performance Improvements
    Several improvements have been made to reduce memory
    allocations and improve overall linting performance. Numbers
    below refer to Regal’s benchmark for linting its own policies.
  - Optimized config loading and parsing, saving around 2.7
    million allocations (#1491).
  - Reduced allocations by approximately 2 million (#1494).
  - Improved the performance of the use-strings-count rule,
    saving almost 1 million allocations (#1465).
  - Optimized reference comparisons and small iteration patterns,
    saving around 300k allocations (#1472).
  - Included performance enhancements alongside an update to the
    external-reference rule to make it more configurable (#1496).
  * OPA v1.3.0
    Regal has been upgraded to use OPA v1.3.0. This brings several
    upstream improvements, including support for the new one-liner
    grouping in formatting (see OPA#6760). (#1459)
  * Bug Fixes
  - Fixed a bug in the handling of Rego input from stdin. Thanks
    @tokyowizard for the report! (#1474)
  - Fixed a panic that could occur in FindConfigRoots when
    supplied with unexpected arguments. (#1487)
  * Other Rule Updates
  - The external-reference rule can now be configured with a
    maximum number of allowed external references, instead of
    solely flagging all external uses within a function. If you
    previously had this rule disabled, you might want to try
    enabling it now, and possibly tweak its configuration to your
    liking. (#1496)
  - The rule-length rule now has a separate setting
    (max-test-rule-length) with a higher default value (60 vs 30)
    for test rules, acknowledging that tests often include
    substantial data. (#1476)
  - Updated documentation for the rule-named-if rule based on
    community feedback received via the page feedback form
    (please let us know if you see issues! & thanks for the
    report!) (#1463)
  * Dependencies
    This release also updates Regals dependencies as follows.
  - github.com/open-policy-agent/opa v1.2.0 -> v1.3.0
  - github.com/prometheus/client_golang v1.21.0 -> v1.21.1
  - go.opentelemetry.io/otel v1.34.0 -> v1.35.0
  - go.opentelemetry.io/otel/metric v1.34.0 -> v1.35.0
  - go.opentelemetry.io/otel/sdk v1.34.0 -> v1.35.0
  - go.opentelemetry.io/otel/trace v1.34.0 -> v1.35.0
  - golang.org/x/crypto v0.35.0 -> v0.36.0
  - golang.org/x/net v0.36.0 -> v0.38.0
  - golang.org/x/sync v0.11.0 -> v0.12.0
  - golang.org/x/sys v0.30.0 -> v0.31.0
  - golang.org/x/text v0.22.0 -> v0.23.0
  - google.golang.org/protobuf v1.36.4 -> v1.36.5
  * Changelog
  - automated: update capabilities by @github-actions in #1458
  - OPA 1.3.0 by @anderseknert in #1459
  - Parameterize some tests by @anderseknert in #1460
  - automated: update capabilities by @github-actions in #1461
  - build(deps): bump the dependencies group with 2 updates by
    @dependabot in #1462
  - docs: rule-named-if by @charlieegan3 in #1463
  - Some perf fixes by @anderseknert in #1465
  - Rule: in-wildcard-key by @anderseknert in #1466
  - Increase coverage by @anderseknert in #1467
  - build(deps): bump github/codeql-action from 3.28.13 to
    3.28.14 in the dependencies group by @dependabot in #1468
  - perf: various improvements by @anderseknert in #1472
  - Rule: confusing-alias by @anderseknert in #1470
  - Add benchmark for testing all rules individually by
    @anderseknert in #1469
  - Rule: mixed-iteration by @anderseknert in #1475
  - Add max-test-rule-length setting to rule-length rule by
    @anderseknert in #1476
  - fix: ensure policy from stdin is enumerated correctly by
    @anderseknert in #1474
  - automated: update capabilities by @github-actions in #1477
  - builtins.RegalIsFormatted: recover from formatter panics by
    @srenatus in #1481
  - automated: update capabilities by @github-actions in #1482
  - build(deps): bump github/codeql-action from 3.28.14 to
    3.28.15 in the dependencies group by @dependabot in #1484
  - Fix unnecessary-some rule not working after OPA 1.0+ by
    @anderseknert in #1485
  - FindConfigRoots: return error, not panic by @srenatus in
    [#1487]
  - perf: Improve how config is parsed, and when by @anderseknert
    in #1491
  - Rule: narrow-argument by @anderseknert in #1488
  - build(deps): bump golang.org/x/net from 0.37.0 to 0.38.0 by
    @dependabot in #1490
  - build(deps): bump codecov/codecov-action from 5.4.0 to 5.4.2
    in the dependencies group by @dependabot in #1495
  - Make external-reference rule less annoying by @anderseknert
    in #1496
  - docs: fix docs that still used v0 syntax by @anderseknert in
    [#1494]
* Fri Mar 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package regal: linter and language server for Rego, bringing
  your policy development experience to the next level
